#!/bin/bash

declare CURRENT_PATH="$(dirname "${BASH_SOURCE[0]-$0}")"

source "$CURRENT_PATH/format_helpers.sh"
source "$CURRENT_PATH/git_helpers.sh"

function __gk_build_prompt() {
  local prompt

  project_name="$(git rev-parse --show-toplevel 2>/dev/null)"
  if [[ ! -z "$project_name" ]]; then
    project_name="$(echo $project_name)"

    prompt=$(__gk_format_repository_name_for "$(basename ${project_name})")

    branch_info="$(git branch -v | grep '*' | head -n 1)"
    branch_name="$(echo "$branch_info" | awk '{ print $2 }')"
    ahead_commits="$(echo "$branch_info" | grep ahead | sed -E 's/.*ahead ([0-9]+).*/\1/g')"
    behind_commits="$(echo "$branch_info" | grep behind | sed -E 's/.*behind ([0-9]+).*/\1/g')"

    if [[ ! -z "$branch_name" ]]; then
      prompt="$(echo "$prompt $(__gk_format_branch_name_for "$branch_name")")"
    fi

    if [[ ! -z "$ahead_commits" ]]; then
      prompt="$(echo "$prompt $(__gk_format_ahead_commits_for "$ahead_commits")")"
    fi

    if [[ ! -z "$behind_commits" ]]; then
      prompt="$(echo "$prompt $(__gk_format_behind_commits_for "$behind_commits")")"
    fi

    tag_name="$(git for-each-ref --points-at=HEAD --count=1 --sort=-version:refname --format='%(refname:short)' refs/tags 2>/dev/null)"
    if [[ ! -z "$tag_name" ]]; then
      prompt="$(echo "$prompt $(__gk_format_tag_name_for "$tag_name")")"
    fi
  fi

  echo "$prompt"
}
